%define anolis_release 16
Name:           jq
Version:        1.6
Release:        %{anolis_release}%{?dist}
Summary:        Command-line JSON processor

License:        MIT and ASL 2.0 and CC-BY and GPLv3
URL:            http://stedolan.github.io/jq/
Source0:        https://github.com/stedolan/jq/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
Patch0:         0000-jq-decimal-literal-number.patch
# Backport of PR#2400 for RHBZ#2017285
Patch1:         jq-fix-non-decimal-string.patch
Patch2:         jq-configure-c99-1.patch
Patch3:         jq-configure-c99-2.patch

# CVE-2023-49355
# Upstream fix: https://github.com/jqlang/jq/commit/7ffb7943d4743e852f277c6a09586e110874b72f
Patch4:         Bugfix-for-CVE-2023-49355.patch

BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  oniguruma-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  chrpath

%ifarch x86_64
BuildRequires:  valgrind
%endif


%description
lightweight and flexible command-line JSON processor

 jq is like sed for JSON data – you can use it to slice
 and filter and map and transform structured data with
 the same ease that sed, awk, grep and friends let you
 play with text.

 It is written in portable C, and it has zero runtime
 dependencies.

 jq can mangle the data format that you have into the
 one that you want with very little effort, and the
 program to do so is often shorter and simpler than
 you'd expect.

%package devel
Summary:	Development files for %{name}
Requires:	%{name} = %{version}-%{release}

%description devel
Development files for %{name}

%package doc
Summary: Documents for %{name}
BuildArch: noarch
Requires: %{name} = %{version}-%{release}

%description  doc
Doc pages for %{name}


%prep
%autosetup -p1 -n %{name}-%{version}

%build
autoreconf -fi
%configure --disable-static
%make_build

%install
%make_install

# Delete build-time RPATH that is unnecessary on an installed
# system - rhbz#1987608
chrpath -d %{buildroot}%{_bindir}/%{name}

rm -fr %{buildroot}%{_datadir}/doc

%check
# Valgrind used, so restrict architectures for check
%ifarch x86_64
make check
%endif

%files
%license COPYING
%{_bindir}/%{name}
%{_libdir}/libjq.so.*
%{_mandir}/man1/jq.1*

%files doc
%doc AUTHORS README README.md

%files devel
%{_includedir}/jq.h
%{_includedir}/jv.h
%{_libdir}/libjq.so

%changelog
* Mon Aug 12 2024 lidongyue <dongyue@nfschina.com> - 1.6-16
- Fix CVE-2023-49355

* Tue Jan 24 2023 Funda Wang <fundawang@yeah.net> - 1.6-15
- Import package for anolis 23
